@@ -2,5 +2,5 @@ from .main_2 import ModelInput, PipelineMatch
 from .main_1 import ModelInputInner, PipelineMatchInner
 from .func.function_image import PipelineImage
 from .func.function_text import PipelineText
-from .func.post_processing import PostProcessing
+from .func.post_processing import PostProcessing, save_parquet_to_csv
 from .pipeline.rerank import ReRank, ReRankConfig
